@@ -1,7 +1,7 @@
 # Two-Stage Least Squares
 #   John Fox
 
-# last modified 3 Sept 06 by J. Fox
+# last modified 26 Sept 07 by J. Fox
 
 tsls <- function(y, ...){
     UseMethod("tsls")
@@ -135,7 +135,7 @@ anova.tsls <- function(object, model.2, s2, dfe, ...){
     SS <- abs(SS.1 - SS.2)
     Df <- abs(dfe.2 - dfe.1)
     if (missing(s2)){
-        s2 <- if (dfe.1 > dfe.2) s2.1 else s2.2
+        s2 <- if (dfe.1 > dfe.2) s2.2 else s2.1
         f <- (SS/Df) / s2
         RSS <- c(SS.1, SS.2)
         Res.Df <- c(dfe.1, dfe.2)
@@ -150,7 +150,7 @@ anova.tsls <- function(object, model.2, s2, dfe, ...){
         RSS <- c(SS.1, SS.2, s2*dfe)
         Res.Df <- c(dfe.1, dfe.2, dfe)
         SS <- c(NA, SS, NA)
-        P <- c(NA, 1 - pf(f, Df, min(dfe.1, dfe.2)), NA)
+        P <- c(NA, 1 - pf(f, Df, dfe), NA)
         Df <- c(NA, Df, NA)
         f <- c(NA, f, NA)
         rows <- c("Model 1", "Model 2", "Error")
